@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2016 - 2024, Gothenburg Bit Factory.
+// Copyright 2016 - 2025, Gothenburg Bit Factory.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -460,6 +460,12 @@ void CLI::canonicalizeNames ()
 
   for (auto& a : _args)
   {
+    // Do not canonicalize the BINARY
+    if (a.hasTag ("BINARY"))
+    {
+      continue;
+    }
+
     auto raw = a.attribute ("raw");
     std::string canonical = raw;
 
