@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2016 - 2022, Thomas Lauf, Paul Beckingham, Federico Hernandez.
+// Copyright 2016 - 2018, 2020, 2022 - 2024, Gothenburg Bit Factory.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -35,7 +35,7 @@
 // timew config name             Remove name
 // timew config                  Show all config
 int CmdConfig (
-  const CLI& cli,
+  CLI& cli,
   Rules& rules,
   Journal& journal)
 {
@@ -87,7 +87,7 @@ int CmdConfig (
 
     change = Rules::setConfigVariable (journal, rules, name, value, confirmation);
 
-    if (!change)
+    if (! change)
     {
       rc = 1;
     }
@@ -107,7 +107,7 @@ int CmdConfig (
       found = true;
     }
 
-    if (!found)
+    if (! found)
     {
       throw format ("No entry named '{1}' found.", name);
     }
