@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2016 - 2024, Gothenburg Bit Factory.
+// Copyright 2016 - 2025, Gothenburg Bit Factory.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -39,6 +39,7 @@ int CmdJoin (
   Journal& journal)
 {
   const bool verbose = rules.getBoolean ("verbose");
+  const bool do_adjust = cli.getHint ("adjust", false);
 
   // Gather IDs and TAGs.
   auto ids = cli.getIds ();
@@ -92,7 +93,7 @@ int CmdJoin (
   database.deleteInterval (first);
   database.deleteInterval (second);
 
-  validate (cli, rules, database, combined);
+  autoAdjust (do_adjust, rules, database, combined);
   database.addInterval (combined, verbose);
 
   journal.endTransaction ();
