@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2016 - 2024, Gothenburg Bit Factory.
+// Copyright 2016 - 2025, Gothenburg Bit Factory.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -57,8 +57,10 @@ Interval                getLatestInterval (Database&);
 Range                   getFullDay        (const Datetime&);
 
 // validate.cpp
-void autoFill (const Rules&, Database&, Interval&);
-bool validate (const CLI& cli, const Rules& rules, Database&, Interval&);
+void fillRange (const Rules&, Database&, Interval&);
+void fillRangeStart (const Rules&, Database&, Interval&);
+void fillRangeEnd (const Rules&, Database&, Interval&);
+bool autoAdjust (bool, const Rules&, Database&, Interval&);
 
 // init.cpp
 bool lightweightVersionCheck (int, const char**);
@@ -89,6 +91,7 @@ void enableDebugMode (bool);
 void setDebugIndicator (const std::string&);
 void setDebugColor (const Color&);
 void debug (const std::string&);
+void warn (const std::string&);
 
 // util.cpp
 std::string escape (const std::string&, int);
